# MIDI_SET_PREFIX(PREFIX)
#---------------------------
AC_DEFUN([MIDI_SET_PREFIX],
[
    unset CDPATH
    # make $PIPE_HOME the default for the installation
    AC_PREFIX_DEFAULT($1)

    if test "x$prefix" = "xNONE"; then
        prefix=$ac_default_prefix
        ac_configure_args="$ac_configure_args --prefix $prefix"
    fi

    if test "x$exec_prefix" = "xNONE"; then
        exec_prefix=$prefix
    fi

])


# MIDI_SET_VERSION_INFO(VERSION, [CURRENT], [REVISION], [AGE])
#----------------------------------------------------------------
# Setup various version information, especially the libtool versioning
AC_DEFUN([MIDI_SET_VERSION_INFO],
[
    midi_version=`echo "$1" | sed -e 's/[[a-z,A-Z]].*$//'`

    midi_major_version=`echo "$midi_version" | \
        sed 's/\([[0-9]]*\).\(.*\)/\1/'`
    midi_minor_version=`echo "$midi_version" | \
        sed 's/\([[0-9]]*\).\([[0-9]]*\)\(.*\)/\2/'`
    midi_micro_version=`echo "$midi_version" | \
        sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\3/'`

    if test -z "$midi_major_version"; then midi_major_version=0
    fi

    if test -z "$midi_minor_version"; then midi_minor_version=0
    fi

    if test -z "$midi_micro_version"; then midi_micro_version=0
    fi

    MIDI_VERSION="$midi_version"
    MIDI_MAJOR_VERSION=$midi_major_version
    MIDI_MINOR_VERSION=$midi_minor_version
    MIDI_MICRO_VERSION=$midi_micro_version

    if test -z "$4"; then MIDI_INTERFACE_AGE=0
    else MIDI_INTERFACE_AGE="$4"
    fi

    MIDI_BINARY_AGE=`expr 100 '*' $MIDI_MINOR_VERSION + $MIDI_MICRO_VERSION`
    MIDI_BINARY_VERSION=`expr 10000 '*' $MIDI_MAJOR_VERSION + \
                          $MIDI_BINARY_AGE`

    AC_SUBST(MIDI_VERSION)
    AC_SUBST(MIDI_MAJOR_VERSION)
    AC_SUBST(MIDI_MINOR_VERSION)
    AC_SUBST(MIDI_MICRO_VERSION)
    AC_SUBST(MIDI_INTERFACE_AGE)
    AC_SUBST(MIDI_BINARY_VERSION)
    AC_SUBST(MIDI_BINARY_AGE)

    AC_DEFINE_UNQUOTED(MIDI_MAJOR_VERSION, $MIDI_MAJOR_VERSION,
                       [MIDI major version number])
    AC_DEFINE_UNQUOTED(MIDI_MINOR_VERSION, $MIDI_MINOR_VERSION,
                       [MIDI minor version number])
    AC_DEFINE_UNQUOTED(MIDI_MICRO_VERSION, $MIDI_MICRO_VERSION,
                       [MIDI micro version number])
    AC_DEFINE_UNQUOTED(MIDI_INTERFACE_AGE, $MIDI_INTERFACE_AGE,
                       [MIDI interface age])
    AC_DEFINE_UNQUOTED(MIDI_BINARY_VERSION, $MIDI_BINARY_VERSION,
                       [MIDI binary version number])
    AC_DEFINE_UNQUOTED(MIDI_BINARY_AGE, $MIDI_BINARY_AGE,
                       [MIDI binary age])

    ESO_SET_LIBRARY_VERSION([$2], [$3], [$4])
])


# MIDI_SET_PATHS
#------------------
# Define auxiliary directories of the installed directory tree.
AC_DEFUN([MIDI_SET_PATHS],
[

    if test -z "$plugindir"; then
        plugindir='${libdir}/esopipes-plugins/${PACKAGE}-${VERSION}'
    fi

    if test -z "$privatelibdir"; then
        privatelibdir='${libdir}/${PACKAGE}-${VERSION}'
    fi    

    htmldir='${datadir}/doc/esopipes/${PACKAGE}-${VERSION}/html'

    if test -z "$pipedocsdir"; then
        pipedocsdir='${datadir}/doc/esopipes/${PACKAGE}-${VERSION}/'
	fi

    if test -z "$configdir"; then
       configdir='${datadir}/${PACKAGE}/config'
    fi

    if test -z "$masksdir"; then
       masksdir='${prefix}/share/esopipes/${PACKAGE}-${VERSION}/masks/'
    fi

    if test -z "$calibtempdir"; then
       calibtempdir='${prefix}/share/esopipes/${PACKAGE}-${VERSION}/calib_data/'
    fi

    if test -z "$scriptsdir"; then
       scriptsdir='${datadir}/esopipes/${PACKAGE}-${VERSION}/scripts'
    fi



    AC_SUBST(plugindir)
    AC_SUBST(privatelibdir)
    AC_SUBST(htmldir)
    AC_SUBST(pipedocsdir)
    AC_SUBST(configdir)
    AC_SUBST(masksdir)
    AC_SUBST(calibtempdir)
    AC_SUBST(scriptsdir)


    # Define a preprocesor symbol for the plugin search paths

    AC_DEFINE_UNQUOTED(MIDI_PLUGIN_DIR, "esopipes-plugins",
                       [Plugin directory tree prefix])

    eval plugin_dir="$plugindir"
    plugin_path=`eval echo $plugin_dir | \
                sed -e "s/\/${PACKAGE}-${VERSION}.*$//"`

    AC_DEFINE_UNQUOTED(MIDI_PLUGIN_PATH, "$plugin_path",
                       [Absolute path to the plugin directory tree])

    eval masks_dir="$masksdir"
    eval calibtemp_dir="$calibtempdir"


    AC_DEFINE_UNQUOTED(MIDI_MASKS, "$masks_dir",
                       [Absolute path to the mask directory tree])

    AC_DEFINE_UNQUOTED(MIDI_CALIBTEMP, "$calibtemp_dir",
                       [Absolute path to the calib_temp directory tree])

])


# MIDI_CREATE_SYMBOLS
#-----------------------
# Define include and library related makefile symbols
AC_DEFUN([MIDI_CREATE_SYMBOLS],
[

    # Symbols for package include file and library search paths

    MIDI_INCLUDES='-I$(top_srcdir)/midi'
    MIDI_LDFLAGS='-L$(top_srcdir)/midi'

    QF_INCLUDES='-I$(top_srcdir)/libqfits -I$(top_builddir)/libqfits/src'
    QF_LDFLAGS=""



    all_includes='$(MIDI_INCLUDES) $CX_INCLUDES $(CPL_INCLUDES) $(EXTRA_INCLUDES) $(QF_INCLUDES)'
    all_ldflags='$(MIDI_LDFLAGS) $(CPL_LDFLAGS) $(EXTRA_LDFLAGS) $(QF_LDFLAGS)'

    # Library aliases

    LIBMIDI='$(top_builddir)/midi/libmidi.la'

    # Substitute the defined symbols

    AC_SUBST(MIDI_INCLUDES)
    AC_SUBST(MIDI_LDFLAGS)

    AC_SUBST(LIBMIDI)

    AC_SUBST(QF_INCLUDES)
    AC_SUBST(QF_LDFLAGS)


    # Check for CPL and user defined libraries
    AC_REQUIRE([CPL_CHECK_LIBS])
    AC_REQUIRE([ESO_CHECK_EXTRA_LIBS])

    all_includes='$(MIDI_INCLUDES) $(CPL_INCLUDES) $(EXTRA_INCLUDES) $(QF_INCLUDES)'
    all_ldflags='$(MIDI_LDFLAGS) $(CPL_LDFLAGS) $(EXTRA_LDFLAGS) $(QF_LDFLAGS)'

    AC_SUBST(all_includes)
    AC_SUBST(all_ldflags)
])

# MIDI_SET_DID(SYMBOL, NAME)
#------------------------------
# Adds a DID identifier string to config.h
AC_DEFUN([MIDI_SET_DID],
[

    if test -n "$1" || test -n "$2"; then
        AC_DEFINE_UNQUOTED($1, "$2",
                  [Product DID identifier the library complies to])
        AC_SUBST(PRODUCT_DID)
    fi

])
