/**********************************************************
***********************************************************
*               European Southern Observatory
*            VLTI MIDI Data Reduction Software
*
* Module name:  midiConst.h
* Description:
*
*
* History:
* 22-Mar-05     (csabet) Created
***********************************************************
**********************************************************/
#ifndef _MIDI_CONST_H
#define _MIDI_CONST_H

/**********************************************************
*   Include files
**********************************************************/

/**********************************************************
*   Constant definitions
**********************************************************/
#include <config.h>

#define MIDI_PIPE_VERSION	PACKAGE_STRING		// OLD: Check envPar.sh and midi_drs.prg
/* #define IAUEXCHANGE_VERSION	"iauex-1.3.3" */
#define IAUEXCHANGE_VERSION	"1"
#define MIDI_QC_DIC_VERSION	"DID-1.11"		// Check ESO-DFS-DIC.MIDI_QC

#define UNAV			"UNAVAILABLE"
#define MIDI_PI                 (3.141592653589793115997963)
#define RAD_TO_ARCSEC           (206264.8062470963551564733)
#define DEG_TO_RAD              (0.017453292519943295474372)
#define HOUR_TO_RAD             (0.261799387799149407829447)
#define MAX_STRING_LENGTH       (256)
#define MIN_STRING_LENGTH       (80)
#define SPEED_OF_LIGHT          (299.792458)	// Speed of light in (1.0e6 m/s)
#define MAX_NUM_OF_REGIONS      (4)		// Maximum number of regions
#define REGIONS_UNDISPERSED	(3)		// Maximum number of regions for UNDISPERSED mode
#define LATITUDE_PARANAL        (-0.429792176)	// Coordinates of Paranal, for baseline related computations (radians)
#define LONGITUDE_PARANAL       (1.228750578)	// Coordinates of Paranal, for baseline related computations (radians)
#define VERY_SMALL_FLOAT        (1.e-30)	// To avoid singularity. Added. csabet 09-Jan-04
#define VERY_SMALL_INT          (1)		// To avoid singularity. Added. csabet 09-Jan-04
#define	ARB_NUM_OF_FRAMES	(20)		// Arbitrary number of frames for zero suntraction! (JM)
#define	ARB_NUM_OF_FRAMETIME	(20)		// Arbitrary number of frametime between 100 frames! (JM)
#define N_BAND_FILT_LONG	(12.96)		// Nband filter upper limit (microns)
#define N_BAND_FILT_SHORT	(7.72)		// Nband filter lower limit (microns)
#define SIC_FILT_LONG		(12.95)		// SiC   filter upper limit (microns)
#define SIC_FILT_SHORT		(10.63)		// SiC   filter lower limit (microns)
#define N8_7_FILT_LONG		(9.41)		// N8.7  filter upper limit (microns)
#define N8_7_FILT_SHORT		(7.87)		// N8.7  filter lower limit (microns)
#define ArIII_FILT_LONG		(9.065)		// ArIII filter upper limit (microns)
#define ArIII_FILT_SHORT	(8.935)		// ArIII filter lower limit (microns)
#define SIV_FILT_LONG		(10.54)		// SIV   filter upper limit (microns)
#define SIV_FILT_SHORT		(10.38)		// SIV   filter lower limit (microns)
#define N11_3_FILT_LONG		(11.58)		// N11.3 filter upper limit (microns)
#define N11_3_FILT_SHORT	(10.98)		// N11.3 filter lower limit (microns)
#define NEII_FILT_LONG		(12.905)	// NeII  filter upper limit (microns)
#define NEII_FILT_SHORT		(12.695)	// NeII  filter lower limit (microns)

//	Peak spectras for wavelength calibration
#define FREQ_PEAK_NeII		(23.4297)
#define WAVELENGTH_PEAK_NeII	(12.7955)
#define FREQ_PEAK_SIV		(28.5818)
#define WAVELENGTH_PEAK_SIV	(10.489)
#define FREQ_PEAK_ArIII		(33.3005)
#define WAVELENGTH_PEAK_ArIII	(9.00272)
#define EXPECTED_PINHOLE_WIDTH	(10)

#define	DET_LIN_WIN_PU		(0.40)		// Detector Linearity window per unit
#define DET_LIN_WIN_MIN		(4)		// Minimum length of window
#define PIXEL_SATURATION	(65535)		// Pixel saturation point

#define	SIZE_SEARCH_REF_PIX	(15.00)		// Search size for Reference Pixel
#define	X1_REF_PIX_ABOPEN	(189.927)       // X coordinate of beam 1 central pinhole	IMAGING
#define	Y1_REF_PIX_ABOPEN	(79.294)        // Y coordinate of beam 1 central pinhole	IMAGING
#define	X2_REF_PIX_ABOPEN	(189.050)       // X coordinate of beam 2 central pinhole	IMAGING
#define	Y2_REF_PIX_ABOPEN	(165.469)       // Y coordinate of beam 2 central pinhole	IMAGING
                                	 
#define	X1_REF_PIX_HS_AOPEN	(189.940)       // X coordinate of beam 1 central pinhole	HIGH_SENS
#define	Y1_REF_PIX_HS_AOPEN	(79.383)        // Y coordinate of beam 1 central pinhole	HIGH_SENS
#define	X2_REF_PIX_HS_AOPEN	(189.258)       // X coordinate of beam 2 central pinhole	HIGH_SENS
#define	Y2_REF_PIX_HS_AOPEN	(164.473)       // Y coordinate of beam 2 central pinhole	HIGH_SENS
                                	 
#define	X1_REF_PIX_HS_BOPEN	(190.145)       // X coordinate of beam 1 central pinhole	HIGH_SENS
#define	Y1_REF_PIX_HS_BOPEN	(80.126)        // Y coordinate of beam 1 central pinhole	HIGH_SENS
#define	X2_REF_PIX_HS_BOPEN	(189.483)       // X coordinate of beam 2 central pinhole	HIGH_SENS
#define	Y2_REF_PIX_HS_BOPEN	(165.219)       // Y coordinate of beam 2 central pinhole	HIGH_SENS
                                	 
#define	X1_REF_PIX_SP_AOPEN	(189.682)       // X coordinate of beam 1 central pinhole	SCI_PHOT
#define	Y1_REF_PIX_SP_AOPEN	(79.038)        // Y coordinate of beam 1 central pinhole	SCI_PHOT
#define	X2_REF_PIX_SP_AOPEN	(188.879)       // X coordinate of beam 2 central pinhole	SCI_PHOT
#define	Y2_REF_PIX_SP_AOPEN	(164.471)       // Y coordinate of beam 2 central pinhole	SCI_PHOT
#define	X3_REF_PIX_SP_AOPEN	(187.246)       // X coordinate of beam 3 central pinhole	SCI_PHOT
#define	Y3_REF_PIX_SP_AOPEN	(219.680)       // Y coordinate of beam 3 central pinhole	SCI_PHOT
                                	 
#define	X1_REF_PIX_SP_BOPEN	(189.886)	// X coordinate of beam 1 central pinhole	SCI_PHOT
#define	Y1_REF_PIX_SP_BOPEN	(79.784) 	// Y coordinate of beam 1 central pinhole	SCI_PHOT
#define	X2_REF_PIX_SP_BOPEN	(189.096)	// X coordinate of beam 2 central pinhole	SCI_PHOT
#define	Y2_REF_PIX_SP_BOPEN	(165.187)	// Y coordinate of beam 2 central pinhole	SCI_PHOT
#define	X3_REF_PIX_SP_BOPEN	(188.435)	// X coordinate of beam 3 central pinhole	SCI_PHOT
#define	Y3_REF_PIX_SP_BOPEN	(28.983) 	// Y coordinate of beam 3 central pinhole	SCI_PHOT

#define	SIZE_SEARCH_DSP_TRN	(15)		// Target search window
#define	X_DSP_TRN		(20)		// X ccordinate of the central pinhole
#define	Y_DSP_TRN		(20)		// Y ccordinate of the central pinhole
#define	SIGMA_DSP_TRN		(2)		// Number of pixels for rejection

#define SIZE_SEARCH_ACQ		(5)		// Target search window in acquisition mode

//	Bad Scan List
#define BSL_TIME_ERROR		(1)		// Bit 1  indicates a TIME error
#define BSL_LOCALOPD_ERROR	(2)		// Bit 2  indicates a LOCALOPD error
#define BSL_OPD_ERROR		(4)		// Bit 3  indicates an OPD error
#define BSL_DATA_ERROR		(8)		// Bit 4  indicates a DATA error
#define BSL_TARTYP_ERROR	(16)		// Bit 5  indicates a TARTYP2 error
#define BSL_DLJ_ERROR		(32)		// Bit 6  indicates a Delay Line Jump error
#define BSL_UNWANTED_REGION	(64)		// Bit 7  indicates an Unwanted Region
#define BSL_SNR_ERROR		(128)		// Bit 8  indicates a Weak Signal / Noise
#define BSL_SKY_SCAN		(256)		// Bit 9  indicates a Sky Background
#define BSL_TARTYPE_CROSS	(512)		// Bit 10 indicates a TarType Cross error
#define BSL_MASKED_CHANNEL	(1024)		// Bit 11 indicates a Masked Channel

#define SCI_PHOT_STNR		(60)		// Statistical Signal Threshold in dB
#define KAPPA_NOISE_LIMIT	(0.1)		// Kappa noise threshold
#define GAUSSIAN_SIGMA_SPAN	(20)		// Span of Gaussian Sigma

//  TO_DO_MIDI_DRS. Do we want to assume that these numbers are always correct???
#define TAB_IMAGING_DATA    	(7)		// Default extension no. of IMAGING_DATA in raw file (first ext. 0)
#define MASK_IMAGING_DATA   	(2)		// Default extension no. of IMAGING_DATA in mask file (first ext. 0)

#define PERCENTAGE_START        (0.1)	// Start percentage of the length used to compute bad scan range
#define DEFAULT_REJECTED_SCANS  (30)	// Default number of rejected scans
#define NOISE_LENGTH_MAX        (15)	// Assumed maximum length of noise section in computation of bad scans
#define UNWANTED_SECTION        (2)   	// Region not to be considered at all in computation of bad scans

#define NOT_A_NUMBER		(sqrt(-1))
#define MIN_FRAMES_PER_SCAN	(0.75)	// Minimum required frames in a scan, below which scan is rejected

#define POST_FFT_SIZE		(256)	// FFT size for post processing

/**********************************************************
*   Enumeration definitions
**********************************************************/

/**********************************************************
*   Type definitions
**********************************************************/

/**********************************************************
*   Global Variables
**********************************************************/

/**********************************************************
*   Function Prototypes
**********************************************************/

/*********************************************************/
#endif
/*********************************************************/
/*********************************************************/
